@@ -1,4 +1,4 @@
-## $Id: plotTDR.R 576 2013-03-28 14:40:09Z sluque $
+## $Id: plotTDR.R 600 2014-01-30 03:31:47Z sluque $
 
 ###_ + Internal Function
 ".night" <- function(time, sunrise.time, sunset.time)
@@ -48,7 +48,7 @@
     ## --------------------------------------------------------------------
     ## Author: Sebastian Luque
     ## --------------------------------------------------------------------
-    nights <- diveMove:::.night(time, sunrise.time, sunset.time)
+    nights <- .night(time, sunrise.time, sunset.time)
     nconcurVars <- ifelse(is.null(concurVars), 0, ncol(concurVars))
     plotrows <- nconcurVars + 1
     ncheight <- 1.35 * (1/plotrows)
