@@ -1,7 +1,7 @@
 library(diveMove)
 
 zz <- system.file(file.path("data", "dives.csv"),
-                  package="diveMove")
+                  package="diveMove", mustWork=TRUE)
 (sealX <- readTDR(zz, concurrentCols=4:6, speed=TRUE,
                   sep=";", na.strings="", as.is=TRUE))
 (dcalib <- calibrateDepth(sealX, dry.thr=3610, zoc.method="offset", offset=3))
